module PhantomForms
  module FormBuilders
    class ValidateFormBuilder < ActionView::Helpers::FormBuilder

      FORM_HELPERS = %w{text_field password_field text_area file_field
                         number_field email_field telephone_field phone_field url_field
                         select collection_select date_select time_select datetime_select}

        delegate :content_tag, to: :@template

        def initialize(*)
          super
          @help_tag, @help_css = if options.fetch(:help, '').to_sym == :block
            [:p, 'help-block']
          else
            [:span, 'help-inline']
          end
        end

        FORM_HELPERS.each do |method_name|
          define_method(method_name) do |name, *args|
            options = args.extract_options!.symbolize_keys!
            content_tag :div, class: "form-group"  do
              #Empty label for hstore inputs. Example: label: nil
              label = options[:label].nil? ? content_tag(:span, nil) : label(name, options[:label], class: 'control-label')
              label +
              content_tag(:div, class: 'controls') do
                if object.respond_to?(:errors)
                  help = object.errors[name].any? ? object.errors[name].join(', ') : options[:help]
                else
                  help = nil
                end
                help = content_tag(@help_tag, class: @help_css) { help } if help
                options[:class] = options[:class].to_s + " form-control"
                args << options.except(:label, :help)
                super(name, *args) + help
              end
            end
          end
        end

        def check_box(name, *args)
          options = args.extract_options!.symbolize_keys!
          content_tag :div, class: "control-group#{(' error' if object.errors[name].any?)}"  do
            content_tag(:div, class: 'controls') do
              args << options.except(:label, :help)
              html = super(name, *args) + ' ' + options[:label]
              label(name, html, class: 'checkbox')
            end
          end
        end

    end

  end
end
